@@ -109,25 +109,25 @@
       (bg-removed-refine "#f0da88")
 
       ;; Graphs
-      (red-graph-0-bg     "#ef7969")
-      (red-graph-1-bg     "#ffaab4")
-      (green-graph-0-bg   "#4faa09")
-      (green-graph-1-bg   "#8fef00")
+      (red-graph-0-bg     "#b0b029")
+      (red-graph-1-bg     "#e0cab4")
+      (green-graph-0-bg   "#90b7c0")
+      (green-graph-1-bg   "#a3dfe5")
       (yellow-graph-0-bg  "#ffcf00")
       (yellow-graph-1-bg  "#f9ff00")
-      (blue-graph-0-bg    "#7090ff")
+      (blue-graph-0-bg    "#7f9fff")
       (blue-graph-1-bg    "#9fc6ff")
-      (magenta-graph-0-bg "#e07fff")
-      (magenta-graph-1-bg "#fad0ff")
-      (cyan-graph-0-bg    "#70d3f0")
-      (cyan-graph-1-bg    "#afefff")
+      (magenta-graph-0-bg "#b0b0d0")
+      (magenta-graph-1-bg "#d0dfdf")
+      (cyan-graph-0-bg    "#6faad9")
+      (cyan-graph-1-bg    "#bfe0ff")
 
       ;; Special hues
       (bg-mode-line  "#99c7ff") (fg-mode-line  "#0a0a1f")
       (bg-accent     "#eecc33") (fg-accent     "#000000")
       (bg-completion "#f0dacf")
       (bg-hover      "#eebb20")
-      (bg-hover-alt  "#afafff")
+      (bg-hover-alt  "#afafef")
       (bg-hl-line    "#f3e0d5")
       (bg-region     "#dadadf")
       (bg-paren      "#8fc0cf")
