@@ -93,17 +93,17 @@
       (bg-cyan-subtle     "#bfefff")
 
       ;; Diffs
-      (bg-added          "#dfffe0")
-      (bg-added-faint    "#e0ffea")
-      (bg-added-refine   "#c3efd3")
+      (bg-added          "#c9ffda")
+      (bg-added-faint    "#d7ffe5")
+      (bg-added-refine   "#b3efcf")
 
-      (bg-changed        "#ffe0b9")
+      (bg-changed        "#ffdfb9")
       (bg-changed-faint  "#ffefcb")
-      (bg-changed-refine "#ffcf9f")
+      (bg-changed-refine "#ffcfa0")
 
-      (bg-removed        "#ffe4dd")
-      (bg-removed-faint  "#ffefea")
-      (bg-removed-refine "#ffcdc0")
+      (bg-removed        "#ffd6e0")
+      (bg-removed-faint  "#ffe9e6")
+      (bg-removed-refine "#f5bfc8")
 
       ;; Graphs
       (red-graph-0-bg     "#ef7969")
@@ -124,7 +124,7 @@
       (bg-accent     "#880044") (fg-accent     "#ffffff")
       (bg-completion "#ccedff")
       (bg-hover      "#ffc09f")
-      (bg-hover-alt  "#feb5ff")
+      (bg-hover-alt  "#f0bfff")
       (bg-hl-line    "#f9e0e5")
       (bg-region     "#d0e6ff")
       (bg-paren      "#7fddd0")
