@@ -124,7 +124,7 @@
       (bg-accent     "#cc88ff") (fg-accent     "#000000")
       (bg-completion "#2f335a")
       (bg-hover      "#004f3f")
-      (bg-hover-alt  "#551f5a")
+      (bg-hover-alt  "#452f5f")
       (bg-hl-line    "#34223f")
       (bg-region     "#16304f")
       (bg-paren      "#2f605e")
@@ -132,7 +132,7 @@
       (bg-warning    "#332910") ; check with warning
       (bg-info       "#1f2a00") ; check with info
 
-      (border        "#504750")
+      (border        "#605760")
       (cursor        "#ff99ff")
       (fg-intense    "#ffffff")
 
@@ -171,11 +171,11 @@
       (accent-2 blue-warmer)
       (accent-3 yellow)
 
-      (mail-0 green-cooler)
-      (mail-1 magenta-cooler)
-      (mail-2 magenta)
-      (mail-3 green-warmer)
-      (mail-4 blue-warmer)
+      (mail-0 blue-warmer)
+      (mail-1 magenta-warmer)
+      (mail-2 green-cooler)
+      (mail-3 magenta-cooler)
+      (mail-4 cyan-cooler)
       (mail-5 yellow-cooler)
 
       (rainbow-0 magenta-warmer)
